
# Slot: term

The gene product or complex that carries out the activity

URI: [gocam:enabledByAssociation__term](https://w3id.org/gocam/enabledByAssociation__term)


## Domain and Range

None &#8594;  <sub>0..1</sub> [InformationBiomacromoleculeTermObject](InformationBiomacromoleculeTermObject.md)

## Parents


## Children

 *  [EnabledByGeneProductAssociation➞term](EnabledByGeneProductAssociation_term.md)
 *  [EnabledByProteinComplexAssociation➞term](EnabledByProteinComplexAssociation_term.md)

## Used by

 * [EnabledByAssociation](EnabledByAssociation.md)
